schemetools
===========

.. automodule:: abjad.tools.schemetools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.schemetools.Scheme.Scheme
      ~abjad.tools.schemetools.SchemeAssociativeList.SchemeAssociativeList
      ~abjad.tools.schemetools.SchemeColor.SchemeColor
      ~abjad.tools.schemetools.SchemeMoment.SchemeMoment
      ~abjad.tools.schemetools.SchemePair.SchemePair
      ~abjad.tools.schemetools.SchemeVector.SchemeVector
      ~abjad.tools.schemetools.SchemeVectorConstant.SchemeVectorConstant
